@@ -33,7 +33,7 @@ $Id$
 #include <tdeglobal.h>
 #include <tdelocale.h>
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeconfig.h>
 #include <tdeaboutdata.h>
 #include <tdeaboutapplication.h>
@@ -48,7 +48,7 @@ $Id$
 // Applet initialization function
 extern "C"
 {
-	KDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
+	TDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
 	{
 		TDEGlobal::locale()->insertCatalogue("kolourpicker");
 		return new KolourPicker(configFile, KPanelApplet::Normal,
