@@ -44,7 +44,7 @@ typedef TQValueList<AdElement> AdElementList;
 
 class AdBlock : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
