@@ -38,7 +38,7 @@ namespace KSB_News {
 
   class ConfigFeeds : public ConfigFeedsBase {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
