@@ -24,7 +24,7 @@
 #include <tdeconfig.h>
 #include <tdeglobal.h>
 #include <tdehtml_part.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <tdepopupmenu.h>
