@@ -14,7 +14,7 @@
 
 extern "C"
 {
-	KDE_EXPORT Plugin* create_plugin()
+	TDE_EXPORT Plugin* create_plugin()
 	{
 		TDEGlobal::locale()->insertCatalogue("lyrics");
 		return new Lyrics();
