@@ -38,7 +38,7 @@ public:
     mhtmlPlugin( TQObject *parent, const char *name, const TQStringList& args );
     virtual bool readInfo( KFileMetaInfo& info, uint what);
 private:
-	TQString decodeRFC2047Phrase(const TQString &msg, bool removeLessGreater=TRUE);
+	TQString decodeRFC2047Phrase(const TQString &msg, bool removeLessGreater=true);
 	TQString decodeRFC2047String(const TQString &msg);
 };
 
